@@ -1,22 +1,37 @@
 from dataclasses import dataclass
-from typing import Optional, List, Iterator, Dict
+from typing import Optional, List, Iterator
 
+from marshy.types import ExternalItemType
+
+from schemey._util import filter_none
+from schemey.json_output_context import JsonOutputContext
 from schemey.schema_abc import SchemaABC, T
 from schemey.schema_error import SchemaError
 
+ARRAY = 'array'
+
 
 @dataclass(frozen=True)
-class ArraySchema(SchemaABC[T]):
-    item_schema: Optional[SchemaABC] = None
+class ArraySchema(SchemaABC[List[T]]):
+    item_schema: Optional[SchemaABC[T]] = None
     min_items: int = 0
     max_items: Optional[int] = None
     uniqueness: bool = False
+    default_value: Optional[List[T]] = None
 
-    def get_schema_errors(self,
-                          item: T,
-                          defs: Optional[Dict[str, SchemaABC]],
-                          current_path: Optional[List[str]] = None,
-                          ) -> Iterator[SchemaError]:
+    @property
+    def item_type(self):
+        return List[self.item_schema.item_type]
+
+    def to_json_schema(self, json_output_context: Optional[JsonOutputContext] = None) -> Optional[ExternalItemType]:
+        json_schema = filter_none(dict(type=ARRAY,
+                                       items=self.item_schema.to_json_schema(json_output_context),
+                                       minItems=self.min_items or None,
+                                       maxItems=self.max_items,
+                                       uniqueness=self.uniqueness or None))
+        return json_schema
+
+    def get_schema_errors(self, item: T, current_path: Optional[List[str]] = None) -> Iterator[SchemaError]:
         if current_path is None:
             current_path = []
         if not isinstance(item, list):
@@ -25,7 +40,7 @@ class ArraySchema(SchemaABC[T]):
         if self.item_schema is not None:
             for index, i in enumerate(item):
                 current_path.append(str(index))
-                yield from self.item_schema.get_schema_errors(i, defs, current_path)
+                yield from self.item_schema.get_schema_errors(i, current_path)
                 current_path.pop()
         if self.min_items is not None and len(item) < self.min_items:
             yield SchemaError(current_path, 'min_items', item)
