@@ -1,5 +1,5 @@
 from enum import Enum
-from typing import Type, Optional, Dict
+from typing import Type, Optional
 
 from schemey.enum_schema import EnumSchema
 from schemey.factory.schema_factory_abc import SchemaFactoryABC, T, NONE_TYPE
@@ -12,8 +12,6 @@ PERMITTED_TYPES = [str, bool, int, float, NONE_TYPE]
 
 class EnumSchemaFactory(SchemaFactoryABC):
 
-    def create(self, type_: Type[T], context: SchemaContext, defs: Dict[str, SchemaABC]) -> Optional[SchemaABC[T]]:
+    def create(self, type_: Type[T], context: SchemaContext) -> Optional[SchemaABC[T]]:
         if issubclass(type_, Enum):
-            values = tuple(t.value for t in type_)
-            if next((v for v in values if v.__class__ not in PERMITTED_TYPES), None) is None:
-                return EnumSchema(values)
+            return EnumSchema(type_)
