@@ -1,6 +1,6 @@
 from abc import abstractmethod, ABC
 from functools import total_ordering
-from typing import TypeVar, Type, Optional, Dict
+from typing import TypeVar, Type, Optional
 
 from schemey.schema_abc import SchemaABC
 from schemey.schema_context import SchemaContext
@@ -14,7 +14,7 @@ class SchemaFactoryABC(ABC):
     priority: int = 100
 
     @abstractmethod
-    def create(self, type_: Type[T], context: SchemaContext, defs: Dict[str, SchemaABC]) -> Optional[SchemaABC[T]]:
+    def create(self, type_: Type[T], context: SchemaContext) -> Optional[SchemaABC[T]]:
         """
         Create a schemey for the type given, or return None if that was not possible
         """
